/*******************************************************************
  ORTCAN Project - VCA Logger

  vca_log.c	- simple logging support

  (C) Copyright 2002 by Pavel Pisa 

  The ORTCAN Project is distributed under the 
  Library Gnu General Public Licence. 
  See file COPYING for details.
 *******************************************************************/

//#ifndef _MSC_VER
//#include <unistd.h>
//#endif /*_MSC_VER*/
#include <stdlib.h>
#include <stdio.h>
#include <sys/types.h>
#include <stdarg.h>
#include <can_vca.h>

void
vca_log_fnc_default(const char *domain, int level,
	const char *format, va_list args);

vca_log_fnc_t *vca_log_output;
FILE *vca_log_default_file;

void
vca_log(const char *domain, int level,
       const char *format, ...)
{
  va_list ap;
  char *s;
  if(vca_log_output==NULL) {
    char *log_fname;
    vca_log_output=vca_log_fnc_default;
    if((log_fname=getenv("VCA_LOG_FILENAME"))!=NULL){
      vca_log_default_file=fopen(log_fname,"a");
    }
    if(vca_log_default_file==NULL)
      vca_log_default_file=stderr;
    if(!vca_debug_flg&&((s=getenv("VCA_DEBUG_FLG"))!=NULL)){
      vca_debug_flg=atoi(s);
    }
  }
  va_start(ap, format);
  (*vca_log_output)(domain,level,format,ap);
  va_end(ap);
}

void
vca_log_redir(vca_log_fnc_t *log_fnc, int add_flags)
{
  if(log_fnc==NULL) log_fnc=vca_log_fnc_default;
  vca_log_output=log_fnc;
}

void
vca_log_fnc_default(const char *domain, int level,
	const char *format, va_list ap)
{
  if(!(level&VCA_LOGL_CONT)) {
    level&=VCA_LOGL_MASK;
    if(!domain) domain="unknown";
    if(level)
      fprintf(vca_log_default_file,"<%d>%s: ",level,domain);
    else
      fprintf(vca_log_default_file,"%s: ",domain);
  }
  vfprintf(vca_log_default_file,format, ap);
  fflush(vca_log_default_file);
}

